@@ -76,6 +76,8 @@ void pathdefaults(pathptr newpath, int x, int y)
    newpath->color = areastruct.color;
    newpath->parts = 0;
    newpath->plist = (genericptr *)NULL;
+   newpath->passed = NULL;
+   newpath->num_params = 0;
 }
 
 /*---------------------------------------*/
@@ -91,6 +93,8 @@ void objectdefaults(objinstptr newinst, objectptr thisobj, int x, int y)
    newinst->thisobject = thisobj;
    newinst->color = DEFAULTCOLOR;
    newinst->params = NULL;
+   newinst->passed = NULL;
+   newinst->num_params = 0;
 }
 
 /*--------------------------------------*/
@@ -118,6 +122,8 @@ void drawdot(int xpos, int ypos)
       (*newarc)->yaxis = 6;
       (*newarc)->width = 1.0;
       (*newarc)->style = FILLED | FILLSOLID | NOBORDER;
+      (*newarc)->num_params = 0;
+      (*newarc)->passed = NULL;
       calcarc(*newarc);
    }
    incr_changes(objectdata);
@@ -158,6 +164,8 @@ void labeldefaults(labelptr newlabel, u_char dopin, int x, int y)
    newlabel->color = areastruct.color;
    newlabel->scale = areastruct.textscale;
    newlabel->string = (stringpart *)malloc(sizeof(stringpart));
+   newlabel->num_params = 0;
+   newlabel->passed = NULL;
 
    /* initialize string with font designator */
    newlabel->string->type = FONT_NAME;
@@ -216,24 +224,25 @@ void textbutton(u_char dopin, XButtonEvent *event)
 
 void charreport(labelptr curlabel)
 {
-   int i, locpos;
-   char *sout = _STR;
+   int i, locpos, cleft = 149;
    stringpart *strptr;
 
+   _STR2[0] = '\0';
    for (i = textpos - MAXCHARS; i <= textpos + MAXCHARS - 1; i++) {
       if (i < 0) continue; 
       strptr = findstringpart(i, &locpos, curlabel->string, NORMINST);
       if (i == textpos) {
-	 strcpy(sout, "| ");
-	 sout += 2; 
+	 strncat(_STR2, "| ", cleft);
+	 cleft -= 2;
       }
       if (strptr == NULL) break;
-      charprint(sout, strptr, locpos);
-      sout += strlen(sout);
-      *sout++ = ' ';
+      charprint(_STR, strptr, locpos);
+      cleft -= strlen(_STR);
+      strncat(_STR2, _STR, cleft);
+      strncat(_STR2, " ", --cleft);
+      if (cleft <= 0) break;
    }
-   *sout++ = '\0';
-   Wprintf(_STR);
+   Wprintf(_STR2);
 }
 
 /*----------------------------------------------------------------------*/
@@ -598,8 +607,11 @@ void rejustify(short mode)
    }
    if (curlabel == NULL)
       Wprintf("No labels chosen to rejustify");
-   else if (changed)
+   else if (changed) {
+      pwriteback(NORMINST);
       incr_changes(objectdata);
+
+   }
 }
 
 /*----------------------------------*/
@@ -619,6 +631,8 @@ void splinedefaults(splineptr newspline, int x, int y)
    newspline->width = areastruct.linewidth;
    newspline->style = areastruct.style;
    newspline->color = areastruct.color;
+   newspline->num_params = 0;
+   newspline->passed = NULL;
    calcspline(newspline);
 }
 
@@ -708,6 +722,8 @@ void arcdefaults(arcptr newarc, int x, int y)
    newarc->yaxis = 0;
    newarc->angle1 = 0;
    newarc->angle2 = 360;
+   newarc->num_params = 0;
+   newarc->passed = NULL;
    calcarc(newarc);
 }
 
@@ -829,6 +845,8 @@ void polydefaults(polyptr newpoly, int number, int x, int y)
    newpoly->width = areastruct.linewidth;
    newpoly->number = number;
    newpoly->points = (pointlist) malloc(number * sizeof(XPoint));
+   newpoly->num_params = 0;
+   newpoly->passed = NULL;
    for (pointptr = newpoly->points; pointptr < newpoly->points + number;
 	pointptr++) {
       pointptr->x = x;
@@ -933,6 +951,8 @@ void startwire(XPoint userpt)
    (*newwire)->number = 2;
    (*newwire)->width = areastruct.linewidth;
    (*newwire)->points = (pointlist) malloc(2 * sizeof(XPoint));
+   (*newwire)->num_params = 0;
+   (*newwire)->passed = NULL;
    pointptr = (*newwire)->points;
    pointptr->x = (pointptr + 1)->x = areastruct.save.x = userpt.x;
    pointptr->y = (pointptr + 1)->y = areastruct.save.y = userpt.y;
@@ -1431,6 +1451,8 @@ void join()
       (*newpoly)->width  = polywidth;
       (*newpoly)->style  = polytype;
       (*newpoly)->color  = polycolor;
+      (*newpoly)->num_params = 0;
+      (*newpoly)->passed = NULL;
 
       /* insert the points into the new polygon */
 
@@ -1479,6 +1501,8 @@ void join()
       (*newpath)->width = polywidth;
       (*newpath)->parts = numpolys;
       (*newpath)->plist = (genericptr *) malloc(numpolys * sizeof(genericptr));
+      (*newpath)->num_params = 0;
+      (*newpath)->passed = NULL;
 
       /* move the elements from the top level into the path structure */
 
