@@ -1327,15 +1327,43 @@ void UDrawLine(objinstptr localdata, XPoint *pt1, XPoint *pt2)
    UDrawSimpleLine(localdata, pt1, pt2); 
 } 
 
+/*----------------------------------------------------------------------*/
+/* Add circle at given point						*/
+/*----------------------------------------------------------------------*/
+
+void UDrawCircle(XPoint *upt, u_char which)
+{
+   XPoint wpt;
+
+   user_to_window(*upt, &wpt);
+   XSetLineAttributes(dpy, areastruct.gc, 0, LineSolid, CapButt, JoinMiter);
+   switch(which) {
+      case P_POSITION_X:
+	 fprintf(stderr, "Draw circle X at %d, %d\n", wpt.x, wpt.y);
+         XDrawArc(dpy, win, areastruct.gc, wpt.x - 3, wpt.y - 3, 6, 6, -45, 45);
+         XDrawArc(dpy, win, areastruct.gc, wpt.x - 3, wpt.y - 3, 6, 6, 135, 225);
+	 break;
+      case P_POSITION_Y:
+	 fprintf(stderr, "Draw circle Y at %d, %d\n", wpt.x, wpt.y);
+         XDrawArc(dpy, win, areastruct.gc, wpt.x - 3, wpt.y - 3, 6, 6, 45, 135);
+         XDrawArc(dpy, win, areastruct.gc, wpt.x - 3, wpt.y - 3, 6, 6, 225, 315);
+	 break;
+      default:
+	 fprintf(stderr, "Draw whole circle at %d, %d\n", wpt.x, wpt.y);
+         XDrawArc(dpy, win, areastruct.gc, wpt.x - 3, wpt.y - 3, 6, 6, 0, 360);
+	 break;
+   }
+}
+
 /*----------------------------------------------------------------------*/
 /* Add "X" at string origin						*/
 /*----------------------------------------------------------------------*/
 
-void UDrawXAt(XPoint *upt)
+void UDrawXAt(XPoint *wpt)
 {
    XSetLineAttributes(dpy, areastruct.gc, 0, LineSolid, CapButt, JoinMiter);
-   XDrawLine(dpy, win, areastruct.gc, upt->x - 3, upt->y - 3, upt->x + 3, upt->y + 3);
-   XDrawLine(dpy, win, areastruct.gc, upt->x + 3, upt->y - 3, upt->x - 3, upt->y + 3);
+   XDrawLine(dpy, win, areastruct.gc, wpt->x - 3, wpt->y - 3, wpt->x + 3, wpt->y + 3);
+   XDrawLine(dpy, win, areastruct.gc, wpt->x + 3, wpt->y - 3, wpt->x - 3, wpt->y + 3);
 }
 
 /*----------------------------------------------------------------------*/
@@ -1344,10 +1372,10 @@ void UDrawXAt(XPoint *upt)
 
 void UDrawX(labelptr curlabel)
 {
-   XPoint upt;
+   XPoint wpt;
 
-   user_to_window(curlabel->position, &upt);
-   UDrawXAt(&upt);
+   user_to_window(curlabel->position, &wpt);
+   UDrawXAt(&wpt);
 }
 
 #ifdef SCHEMA
@@ -1358,10 +1386,10 @@ void UDrawX(labelptr curlabel)
 
 void UDrawXDown(labelptr curlabel)
 {
-   XPoint upt;
+   XPoint wpt;
 
-   UTransformbyCTM(DCTM, &curlabel->position, &upt, 1);
-   UDrawXAt(&upt);
+   UTransformbyCTM(DCTM, &curlabel->position, &wpt, 1);
+   UDrawXAt(&wpt);
 }
 
 /*-------------------------------------------------------------------------*/
@@ -1696,6 +1724,9 @@ void UDrawObject(objinstptr localdata, objectptr theobject, short level,
    if (bboxout[xm].x < areastruct.width && bboxout[ym].y < areastruct.height &&
        bboxout[1 - xm].x > 0 && bboxout[1 - ym].y > 0) {       
 
+     /* make parameter substitutions */
+     psubstitute(localdata);
+
      /* draw all of the elements */
    
      tmpwidth = UTopTransScale(xobjs.pagelist[areastruct.page]->wirewidth);
@@ -1734,11 +1765,13 @@ void UDrawObject(objinstptr localdata, objectptr theobject, short level,
 	     break;
    
           case(OBJECT):
-	     if ((!areastruct.editinplace) ||
-			(TOOBJINST(areagen)->thisobject != objectdata) ||
-			(TOOBJINST(areagen) != areastruct.topobject))
+	     if ((!areastruct.editinplace) || (TOOBJINST(areagen)->thisobject
+			!= objectdata) || ((pushlist != NULL) && (TOOBJINST(areagen)!=
+			pushlist->thisinst))) {
+
                 UDrawObject(TOOBJINST(areagen), TOOBJINST(areagen)->thisobject,
 			level + 1, curcolor);
+	     }
 	     break;
    
   	  case(LABEL): 
