@@ -71,9 +71,9 @@ static char *function_names[NUM_FUNCTIONS] = {
    "Overline", "ISO Encoding", "Return", "Halfspace", "Quarterspace",
    "Special", "Tab Stop", "Tab Forward", "Tab Backward",
    "Text Return", "Text Delete", "Text Right", "Text Left",
-   "Text Home", "Text End", "Return Char",
-   "Parameter", "Edit Break", "Edit Delete", "Edit Insert",
-   "Edit Next", "Attach", "Next Library", "Library Directory",
+   "Text Home", "Text End", "Return Char", "Parameter",
+   "Parameterize Point", "Break at Point", "Delete Point", "Insert Point",
+   "Next Point", "Attach", "Next Library", "Library Directory",
    "Library Move", "Library Copy", "Library Edit", "Library Delete",
    "Library Duplicate", "Library Hide", "Page Directory ", "Library Pop",
    "Help", "Redraw", "View", "Zoom In", "Zoom Out", "Pan",
@@ -350,6 +350,53 @@ char *key_to_string(int keywstate)
    return kptr;
 }
 
+/*--------------------------------------------------------------*/
+/* Print the bindings for the (polygon) edit functions		*/
+/*--------------------------------------------------------------*/
+
+void printeditbindings()
+{
+   char *tstr;
+
+   _STR2[0] = '\0';
+
+   tstr = key_to_string(firstbinding(XCF_Edit_Break));
+   strcat(_STR2, tstr);
+   strcat(_STR2, "=");
+   strcat(_STR2, func_to_string(XCF_Edit_Break));
+   strcat(_STR2, ", ");
+   free(tstr);
+
+   tstr = key_to_string(firstbinding(XCF_Edit_Delete));
+   strcat(_STR2, tstr);
+   strcat(_STR2, "=");
+   strcat(_STR2, func_to_string(XCF_Edit_Delete));
+   strcat(_STR2, ", ");
+   free(tstr);
+
+   tstr = key_to_string(firstbinding(XCF_Edit_Insert));
+   strcat(_STR2, tstr);
+   strcat(_STR2, "=");
+   strcat(_STR2, func_to_string(XCF_Edit_Insert));
+   strcat(_STR2, ", ");
+   free(tstr);
+
+   tstr = key_to_string(firstbinding(XCF_Edit_Param));
+   strcat(_STR2, tstr);
+   strcat(_STR2, "=");
+   strcat(_STR2, func_to_string(XCF_Edit_Param));
+   strcat(_STR2, ", ");
+   free(tstr);
+
+   tstr = key_to_string(firstbinding(XCF_Edit_Next));
+   strcat(_STR2, tstr);
+   strcat(_STR2, "=");
+   strcat(_STR2, func_to_string(XCF_Edit_Next));
+   free(tstr);
+
+   Wprintf(_STR2);
+}
+
 /*--------------------------------------------------------------*/
 /* Remove a key binding from the list				*/
 /*--------------------------------------------------------------*/
@@ -505,6 +552,7 @@ void default_keybindings()
    add_binding(XK_backslash, XCF_Special);
    add_binding(ALT | XK_c, XCF_Special);
    add_binding(ALT | XK_p, XCF_Parameter);
+   add_binding(XK_p, XCF_Edit_Param);
    add_binding(XK_x, XCF_Edit_Break);
    add_binding(XK_d, XCF_Edit_Delete);
    add_binding(XK_Delete, XCF_Edit_Delete);
