@@ -314,6 +314,8 @@ objinstptr makeinstofpage(objectptr libinst, objectptr libobj)
    (*drawinst)->rotation = 0;
    (*drawinst)->params = NULL;		/* values are the defaults */
    (*drawinst)->thisobject = libobj;
+   (*drawinst)->num_params = 0;
+   (*drawinst)->passed = NULL;
    libinst->parts++;
    return *drawinst;
 }
@@ -378,6 +380,8 @@ void composepagelib(short mode)
       (*drawbox)->width = 1.0;
       (*drawbox)->number = 4;
       (*drawbox)->points = (pointlist) malloc(4 * sizeof(XPoint));
+      (*drawbox)->num_params = 0;
+      (*drawbox)->passed = NULL;
       pointptr = (*drawbox)->points;
       pointptr->x = (i % gxsize) * xdel + margin;
       pointptr->y = -(i / gxsize) * ydel - margin;
@@ -401,6 +405,8 @@ void composepagelib(short mode)
 	 (*pagelabel)->color = DEFAULTCOLOR;
 	 (*pagelabel)->scale = 0.75;
 	 (*pagelabel)->string->data.font = fval;
+         (*pagelabel)->num_params = 0;
+         (*pagelabel)->passed = NULL;
 	 strptr = makesegment(&((*pagelabel)->string), NULL);
 	 strptr->type = TEXT_STRING;
 	 strptr->data.string = (char *) malloc(1 + strlen(libobj->name));
@@ -599,6 +605,8 @@ void composelib(short mode)
       (*drawinst)->scale = 1.0;
       (*drawinst)->params = NULL;	/* library object has all default values */
       (*drawinst)->thisobject = (*libobj);
+      (*drawinst)->num_params = 0;
+      (*drawinst)->passed = NULL;
 
       (*drawinst)->position.x = xpos - (*libobj)->_lowerleft.x;
       if ((*libobj)->_width <= 170) (*drawinst)->position.x += 
@@ -635,7 +643,6 @@ void composelib(short mode)
 			(*libobj)->_lowerleft.y - 10;
          else
             (*drawname)->position.y = ypos - 180;
-
       }
       else (libinst->parts++);
       xpos = nxpos;
@@ -974,9 +981,13 @@ void copycat()
 	 (*newobj)->params[i] = (oparamptr) malloc(sizeof(oparam));
 	 (*newobj)->params[i]->type = oldobj->params[i]->type;
 	 switch (oldobj->params[i]->type) {
-	    case XC_SHORT:
-	       (*newobj)->params[i]->parameter.svalue =
-			oldobj->params[i]->parameter.svalue;
+	    case XC_INT:
+	       (*newobj)->params[i]->parameter.ivalue =
+			oldobj->params[i]->parameter.ivalue;
+	       break;
+	    case XC_FLOAT:
+	       (*newobj)->params[i]->parameter.fvalue =
+			oldobj->params[i]->parameter.fvalue;
 	       break;
 	    case XC_STRING:
 	       (*newobj)->params[i]->parameter.string =
@@ -1015,6 +1026,8 @@ void copycat()
 	       (*npath)->parts = 0;
 	       (*npath)->plist = (genericptr *)malloc(cpath->parts *
 			sizeof(genericptr));
+               (*npath)->num_params = 0;
+               (*npath)->passed = NULL;
 	       for (gpart = cpath->plist; gpart < cpath->plist + cpath->parts;
 			gpart++) {
 		  switch((*gpart)->type){
@@ -1077,6 +1090,8 @@ void copycat()
 	       (*nlabel)->scale = clabel->scale;
 	       (*nlabel)->justify = clabel->justify;
 	       (*nlabel)->string = stringcopy(clabel->string);
+	       (*nlabel)->num_params = 0;
+	       (*nlabel)->passed = NULL;
 #ifdef SCHEMA
 	       (*nlabel)->pin = clabel->pin;
 #endif
@@ -1093,6 +1108,8 @@ void copycat()
 	       (*ninst)->position.y = cinst->position.y;
 	       (*ninst)->scale = cinst->scale;
 	       (*ninst)->thisobject = cinst->thisobject;
+	       (*ninst)->num_params = 0;
+	       (*ninst)->passed = NULL;
 
 	       /* Library instance's parameter list is always default (null) */
 	       (*ninst)->params = NULL;
@@ -1209,6 +1226,8 @@ void catbutton(u_int mode, XButtonEvent *event)
 		     (*newobject)->position.y = TOOBJINST(libpage->plist +
 		            *newselect)->position.y + ydiff;
 		     (*newobject)->params = NULL;
+	       	     (*newobject)->num_params = 0;
+	       	     (*newobject)->passed = NULL;
 	             u2u_snap(&((*newobject)->position));
 		     *newselect = (short)(newobject - (objinstptr *)objectdata->plist);
 		     if ((*newobject)->thisobject == (*libobj)->thisobject)
@@ -1227,6 +1246,8 @@ void catbutton(u_int mode, XButtonEvent *event)
                      (*newobject)->position.x = areastruct.save.x;
 	             (*newobject)->position.y = areastruct.save.y; 
 		     (*newobject)->params = NULL;
+	       	     (*newobject)->num_params = 0;
+	       	     (*newobject)->passed = NULL;
 
 	             /* add this object to the list of selected items */
 
