@@ -745,6 +745,7 @@ void setosize(Widget w, objinstptr dataptr)
       }
    }
    objectdeselect();
+   pwriteback(NORMINST);
    drawarea(NULL, NULL, NULL);
 }
 
@@ -836,6 +837,7 @@ void setwwidth(Widget w, void *dataptr)
          }
       }
       objectdeselect();
+      pwriteback(NORMINST);
       drawarea(NULL, NULL, NULL);
    }
 }
@@ -1110,6 +1112,7 @@ void setcolorscheme(Boolean boolvalue)
 {
    if (boolvalue) {
       BBOXCOLOR = appdata.bboxpix;
+      PARAMCOLOR = appdata.parampix;
       AUXCOLOR = appdata.auxpix;
       BARCOLOR = appdata.barpix;
       OFFBUTTONCOLOR = appdata.buttonpix;
@@ -1124,6 +1127,7 @@ void setcolorscheme(Boolean boolvalue)
    }
    else {
       BBOXCOLOR = appdata.bboxpix2;
+      PARAMCOLOR = appdata.parampix2;
       AUXCOLOR = appdata.auxpix2;
       BARCOLOR = appdata.barpix2;
       OFFBUTTONCOLOR = appdata.buttonpix2;
@@ -1621,7 +1625,9 @@ void getfill(Widget w, u_int value, caddr_t nulldata)
 	 }
       }
    }
-   if (!selected) {
+   if (selected)
+      pwriteback(NORMINST);
+   else {
       if (value & BBOX) {
 	 Wprintf("Cannot set default style to Bounding Box");
 	 areastruct.style &= ~BBOX;
@@ -1880,7 +1886,7 @@ void startparam(Widget w, u_int value, caddr_t calldata)
 {
    genericptr *settext;
 
-   if (value == LABEL) {
+   if (value == P_SUBSTRING) {
       if (eventmode == TEXT2_MODE || eventmode == TEXT3_MODE) {
          settext = (genericptr *)EDITPART;
          makeparam(TOLABEL(settext));
@@ -1944,6 +1950,7 @@ void doflipflip(Widget w, labelptr settext)
       undrawtext(settext);
       settext->justify = newjust;
       redrawtext(settext);
+      pwriteback(NORMINST);
    }
    else {
       boolval = (areastruct.justify & FLIPINV) ? True : False;
@@ -1972,6 +1979,7 @@ void dopinvisible(Widget w, labelptr settext)
       undrawtext(settext);
       settext->justify = newjust;
       redrawtext(settext);
+      pwriteback(NORMINST);
       if (w != NULL) toggle(w, &boolval, NULL);
    }
 }
@@ -1996,6 +2004,7 @@ void setjust(Widget w, u_int value, labelptr settext, short mode)
       undrawtext(settext);
       settext->justify = newjust;
       redrawtext(settext);
+      pwriteback(NORMINST);
    }
    else {
       if (mode == 1)
@@ -2619,3 +2628,10 @@ void fill_popup(Widget w, caddr_t clientdata, caddr_t calldata)
 }
 
 /*-------------------------------------------------------------------------*/
+
+void param_popup(Widget w, caddr_t clientdata, caddr_t calldata)
+{ 
+   position_popup(w, ParametersSubstringButton);
+}
+
+/*-------------------------------------------------------------------------*/
