@@ -144,6 +144,20 @@ menustruct Colors[] = {
 	{"_White", action(setcolor, NULL)},
 };
 
+menustruct Parameterize[] = {
+	{"Substring", action(startparam, Number(P_SUBSTRING))},
+	{"Position", action(startparam, Number(P_POSITION))},
+	{"Style", action(startparam, Number(P_STYLE))},
+	{"Justification", action(startparam, Number(P_JUSTIFY))},
+	{"Start Angle", action(startparam, Number(P_ANGLE1))},
+	{"End Angle", action(startparam, Number(P_ANGLE2))},
+	{"Radius", action(startparam, Number(P_RADIUS))},
+	{"Minor Axis", action(startparam, Number(P_MINOR_AXIS))},
+	{"Rotation", action(startparam, Number(P_ROTATION))},
+	{"Scale", action(startparam, Number(P_SCALE))},
+	{"Linewidth", action(startparam, Number(P_LINEWIDTH))},
+};
+
 menustruct Stipples[] = {
 	{":Black",  action(getfill, Number(FILLED | FILLSOLID))},
 	{":Gray12", action(getfill, Number(FILLED | STIP2 | STIP1))},
@@ -165,8 +179,8 @@ menustruct TextMenu[] = {
 	{"Encoding", submenu(FontEncodings)},
 	{"Insert", submenu(TextSpacing)},             
 	{"Justification (keypad)", submenu(Justifs)},
-	{"Parameterize", action(startparam, Number(LABEL))},
-	{"Unparameterize", action(startunparam, Number(LABEL))},
+	{"Parameterize", action(startparam, Number(P_SUBSTRING))},
+	{"Unparameterize", action(startunparam, Number(P_SUBSTRING))},
 	{" ", noaction},
 	{"Make Label (t)", action(starttext, Number(NORMAL))},
 };
@@ -177,8 +191,7 @@ menustruct PolyMenu[] = {
 	{"Color", submenu(Colors)},
 	{" ", noaction},
 	{"Object size", action(getosize, NULL)},
-/*	{"Parameterize", action(startparam, Number(0))},	*/
-/*	{"Unparameterize", action(startunparam, Number(0))},	*/
+	{"Parameters", submenu(Parameterize)},
 	{"Center Object", setaction(toggle, &areastruct.center)},
 	{"Manhattan Draw", action(toggle, &areastruct.manhatn)},
 	{"Polygon Edit", submenu(BoxEditStyles)},
@@ -353,9 +366,9 @@ toolbarstruct ToolBar[] = {
 		"rotate 15 degrees clockwise"},
 	{"RotN",  ccw_xpm, toolaction(startrotate, Number(-3)),
 		"rotate 15 degrees counterclockwise"},
-	{"HFlip",  hf_xpm, toolaction(startrotate, Number(512)),
+	{"HFlip",  fx_xpm, toolaction(startrotate, Number(512)),
 		"flip horizontal"},
-	{"VFlip",  vf_xpm, toolaction(startrotate, Number(1024)),
+	{"VFlip",  fy_xpm, toolaction(startrotate, Number(1024)),
 		"flip vertical"},
 	{"Push",  pu2_xpm, toolaction(startpush, NULL),
 		"push (edit object)"},
@@ -363,7 +376,7 @@ toolbarstruct ToolBar[] = {
 		"pop (return from object edit)"},
 	{"Make",   mk_xpm, toolaction(selectsave, NULL),
 		"make an object from selected elements"},
-	{"Join",   j4_xpm, toolaction(join, NULL),
+	{"Join",   pz_xpm, toolaction(join, NULL),
 		"join elements into polygon or path"},
 	{"Unjoin", uj_xpm, toolaction(unjoin, NULL),
 		"separate path into elements"},
@@ -373,6 +386,8 @@ toolbarstruct ToolBar[] = {
 		"set border and line properties"},
 	{"Fills",  fi_xpm, toolaction(fill_popup, NULL),
 		"set fill properties"},
+	{"Parameters", pm_xpm,  toolaction(param_popup, NULL),
+		"parameterize properties"},
 	{"Library",li_xpm, toolaction(changecat, NULL),
 		"go to next library"},
 	{"Libdir", yp_xpm, toolaction(startcatalog, Number(LIBLIB)),
