@@ -155,7 +155,9 @@ extern Boolean elemcompare(genericptr *, genericptr *);
 extern short objcompare(objectptr, objectptr);
 extern float getpsscale(float, short);
 extern void dostcount(FILE *, short *, short);
-extern void varcheck(FILE *, short *, objectptr, int, short *);
+extern void varcheck(FILE *, short, objectptr, short *, genericptr, u_char);
+extern void varfcheck(FILE *, float, objectptr, short *, genericptr, u_char);
+extern void varpcheck(FILE *, short, objectptr, int, int, short *, genericptr, u_char);
 extern void getfile(Widget, void *, caddr_t);
 extern Boolean nextfilename();
 extern void loadfontlib();
@@ -170,7 +172,10 @@ extern void importfile();
 extern void loadfile(short);
 extern void readlabel(objectptr, char *, stringpart **);
 extern u_char *find_match(u_char *);
-extern void varscan(objectptr, char *, short *);
+extern char *advancetoken(char *);
+extern char *varpscan(objectptr, char *, short *, genericptr, int, int, u_char);
+extern char *varscan(objectptr, char *, short *, genericptr, u_char);
+extern char *varfscan(objectptr, char *, float *, genericptr, u_char);
 extern Boolean objectread(FILE *, objectptr, short, short, short, char *, int);
 extern void setfile(Widget, Widget, caddr_t);
 extern XtTimerCallbackProc savetemp(Widget, XtIntervalId *);
@@ -262,6 +267,7 @@ extern void refresh(Widget, caddr_t, caddr_t);
 extern void zoomview(Widget, caddr_t, caddr_t);
 extern void UDrawSimpleLine(objinstptr, XPoint *, XPoint *);
 extern void UDrawLine(objinstptr, XPoint *, XPoint *);
+extern void UDrawCircle(XPoint *, u_char);
 extern void UDrawX(labelptr);
 #ifdef SCHEMA
 extern void UDrawXDown(labelptr);
@@ -299,6 +305,7 @@ extern int string_to_key(const char *);
 extern char *binding_to_string(int, int);
 extern char *func_to_string(int);
 extern char *key_to_string(int);
+extern void printeditbindings();
 extern int add_vbinding(int, int, short);
 extern int add_binding(int, int);
 extern int add_keybinding(const char *, const char *);
@@ -419,6 +426,7 @@ extern void position_popup(Widget, Widget);
 extern void border_popup(Widget, caddr_t, caddr_t);
 extern void color_popup(Widget, caddr_t, caddr_t);
 extern void fill_popup(Widget, caddr_t, caddr_t);
+extern void param_popup(Widget, caddr_t, caddr_t);
 extern void dospecial(void);
 
 /* from netlist.c: */
@@ -474,15 +482,15 @@ extern void clearpins(objectptr);
 
 /* from parameter.c: */ 
 
-extern void rehook(objectptr, char *, char *);
-extern void hookexpand(objectptr, char *, short);
-extern void makeshortp(genericptr *);
-extern void unmakeshortp(genericptr *);
+extern void indicateparams(genericptr);
+extern void makenumericalp(genericptr *, u_int);
+extern void unmakenumericalp(genericptr *, u_int);
 extern void noparmstrcpy(u_char *, u_char *);
 extern void insertparam();
 extern void makeparam(labelptr);
 extern void initinst(objectptr, objectptr, short);
 extern void searchinst(objectptr, objectptr, short);
+extern void initallinstances(objectptr, int);
 extern stringpart *searchparam(stringpart *);
 extern void unmakeparam(labelptr, stringpart *);
 extern void unparameterize(u_int);
@@ -491,6 +499,7 @@ extern genericptr findparam(objectptr, void *, u_char);
 extern Boolean paramcross(objectptr, labelptr);
 extern oparamptr parampos(objectptr, labelptr, char *, short *, short *);
 extern void psubstitute(objinstptr);
+extern void pwriteback(objinstptr);
 extern short paramlen(u_char *);
 extern int natstrlen(u_char *);
 extern int natstrcmp(u_char *, u_char *);
