@@ -61,6 +61,8 @@ static char *q_xpm[] = {
 "...................."};
 #endif
 
+PyObject *xcmod;
+
 /*----------------------------------------------------------------------*/
 /* Local includes                                                       */
 /*----------------------------------------------------------------------*/
@@ -862,9 +864,12 @@ static PyObject *xc_getobject(PyObject *self, PyObject *args)
    if (thisobj->num_params > 0) {
       dlist = PyList_New(thisobj->num_params);
       for (i = 0; i < thisobj->num_params; i++) {
-	 if (thisobj->params[i]->type == XC_SHORT)
+	 if (thisobj->params[i]->type == XC_INT)
             PyList_SetItem(dlist, i,
-		PyInt_FromLong((long)(thisobj->params[i]->parameter.svalue)));
+		PyInt_FromLong((long)(thisobj->params[i]->parameter.ivalue)));
+	 else if (thisobj->params[i]->type == XC_FLOAT)
+            PyList_SetItem(dlist, i,
+		PyFloat_FromDouble((double)(thisobj->params[i]->parameter.fvalue)));
 	 else if (thisobj->params[i]->type == XC_STRING)
             PyList_SetItem(dlist, i,
 		PyGetStringParts(thisobj->params[i]->parameter.string));
@@ -1838,13 +1843,36 @@ static PyObject *xc_newtool(PyObject *self, PyObject *args)
    return PyInt_FromLong((long)status);
 }
 
-/*--------------------------------------------------------------*/
-/* Return a list of the widgets in tooldict			*/
-/*--------------------------------------------------------------*/
+/*------------------------------------------------------------------*/
+/* Return a list of the widgets in tooldict			    */
+/* (memory for list is allocated here and must be free'd elsewhere) */
+/*------------------------------------------------------------------*/
  
 Widget *pytoolbuttons(int *num_tools)
 {
-   return NULL;		/* No action, yet */
+   Widget *ptools;
+   PyObject *rval, *pdict, *pmod;
+   int i;
+
+   if (xcmod == NULL) {
+      *num_tools = 0;
+      return NULL;
+   }
+   pdict = PyModule_GetDict(xcmod);
+   rval = PyRun_String("len(tooldict)", Py_eval_input, pdict, pdict); /* ? */
+   *num_tools = (int)PyInt_AsLong(rval);
+   fprintf(stderr, "num_tools = %d\n", *num_tools);
+
+   if (*num_tools <= 0) return NULL;
+
+   ptools = (Widget *)malloc(*num_tools * sizeof(Widget));
+
+   for (i = 0; i < *num_tools; i++) {
+      sprintf(_STR2, "tooldict[%d]", i);
+      rval = PyRun_String(_STR2, Py_eval_input, pdict, pdict);
+      ptools[i] = (Widget)((int)PyInt_AsLong(rval));
+   }
+   return ptools;
 }
 
 #endif
@@ -1909,7 +1937,7 @@ void init_interpreter()
    Py_SetProgramName("XCircuit");
    Py_Initialize();
    PyImport_AddModule("xc");
-   Py_InitModule("xc", xc_methods);
+   xcmod = Py_InitModule("xc", xc_methods);
    PyRun_SimpleString("from xc import *\n");
    PyRun_SimpleString("keydict = {}\n");	/* initialize key/function pairs */
    PyRun_SimpleString("buttondict = {}\n");  /* initialize button/function pairs */
