@@ -553,6 +553,8 @@ void copypinlabel(labelptr pinlab)
       (*newlabel)->color = pinlab->color;
       (*newlabel)->scale = pinlab->scale;
       (*newlabel)->string = stringcopy(pinlab->string);
+      (*newlabel)->num_params = 0;
+      (*newlabel)->passed = NULL;
 
       /* place label just outside bounding box, then recompute bbox */
 
@@ -745,6 +747,8 @@ void swapschem(Widget w, u_int mode, caddr_t calldata)
 	       (*pinlab)->justify = areastruct.justify; 
 	       (*pinlab)->position.x = 0;
 	       (*pinlab)->position.y = objectdata->parts * (TEXTHEIGHT + 10);
+	       (*pinlab)->num_params = 0;
+	       (*pinlab)->passed = NULL;
 	       u2u_snap(&((*pinlab)->position));
 	       (*pinlab)->string = stringcopy(lpin->string);
 	       objectdata->parts++;
