@@ -124,9 +124,14 @@ void gendrawselected(short *newselect, objectptr curobj, objinstptr curinst)
    XSetFunction(dpy, areastruct.gc, GXcopy);
    XSetForeground(dpy, areastruct.gc, BACKGROUND);
    geneasydraw(*newselect, DOFORALL, curobj, curinst);
+   indicateparams(*(curobj->plist + *newselect));
+
    XSetFunction(dpy, areastruct.gc, GXxor);
    XSetForeground(dpy, areastruct.gc, SELECTCOLOR ^ BACKGROUND);
    geneasydraw(*newselect, DOFORALL, curobj, curinst);
+
+   XSetForeground(dpy, areastruct.gc, PARAMCOLOR ^ BACKGROUND);
+   indicateparams(*(curobj->plist + *newselect));
 }
 
 /*---------------------------------------------------*/
@@ -162,12 +167,14 @@ void setoptionmenu()
       setallstylemarks(areastruct.style);
       setcolormark(areastruct.color);
       setdefaultfontmarks();
+      setparammarks(NULL);
       return;
    }
 
    for (mselect = areastruct.selectlist; mselect < areastruct.selectlist +
 	areastruct.selects; mselect++) {
       setcolormark(SELTOCOLOR(mselect));
+      setparammarks(SELTOGENERIC(mselect));
       switch(SELECTTYPE(mselect)) {
 	 case ARC:
 	    setallstylemarks(SELTOARC(mselect)->style);
