@@ -183,6 +183,8 @@ static XtResource resources[] = {
       XtOffset(ApplicationDataPtr, barpix), XtRString, "Tan"},
   { "bboxcolor", "BBoxColor", XtRPixel, sizeof(Pixel),
       XtOffset(ApplicationDataPtr, bboxpix), XtRString, "Orange"},
+  { "paramcolor", "ParamColor", XtRPixel, sizeof(Pixel),
+      XtOffset(ApplicationDataPtr, parampix), XtRString, "Plum3"},
 
   /* Color scheme 2 */
 
@@ -210,6 +212,8 @@ static XtResource resources[] = {
       XtOffset(ApplicationDataPtr, barpix2), XtRString, "Tan"},
   { "bboxcolor2", "BBoxColor", XtRPixel, sizeof(Pixel),
       XtOffset(ApplicationDataPtr, bboxpix2), XtRString, "Orange4"},
+  { "paramcolor2", "ParamColor", XtRPixel, sizeof(Pixel),
+      XtOffset(ApplicationDataPtr, parampix2), XtRString, "Plum3"},
 
   /* Other XDefaults-set properties */
 
@@ -2073,6 +2077,7 @@ int main(int argc, char *argv[])
    xobjs.new_changes = 0;
    xobjs.tempfile = NULL;
    signal(SIGINT, dointr);
+   printtime_id = 0;
 
    /* Set the temporary directory name as compiled, unless overridden by */
    /* environment variable "TMPDIR".					 */
