@@ -50,6 +50,7 @@
 #define SELTOARC(a)	TOARC(objectdata->plist + (*a))
 #define SELTOSPLINE(a)	TOSPLINE(objectdata->plist + (*a))
 #define SELTOPATH(a)	TOPATH(objectdata->plist + (*a))
+#define SELTOGENERIC(a) (*(objectdata->plist + (*a)))
 
 /* creation of new elements */
 
@@ -373,6 +374,25 @@ typedef XfPoint* fpointlist;
 #define PATH	32
 #define SEL_ANY	63  /* for selection mechanism only */
 
+/*----------------------------------------------------------------------*/
+/* Allowed parameterization types					*/
+/*----------------------------------------------------------------------*/
+
+#define P_POSITION	0	/* mode only, not a real parameter */
+#define P_SUBSTRING	1
+#define P_POSITION_X	2
+#define P_POSITION_Y	3
+#define P_STYLE		4
+#define P_JUSTIFY	5
+#define P_ANGLE1	6
+#define P_ANGLE2	7
+#define P_RADIUS	8
+#define P_MINOR_AXIS	9
+#define P_ROTATION	10
+#define P_SCALE		11
+#define P_LINEWIDTH	12
+#define P_COLOR		13
+
 /*----------------------------------------------------------------------*/
 /* Labels are constructed of strings and executables 			*/
 /*----------------------------------------------------------------------*/
@@ -396,6 +416,28 @@ typedef struct _stringpart {
 /* structures of all main elements which can be displayed & manipulated	*/
 /*----------------------------------------------------------------------*/
 
+/*----------------------------------------------------------------------*/
+/* Object & object instance parameter structure				*/
+/* (Add types as necessary)						*/
+/*----------------------------------------------------------------------*/
+
+enum paramtypes {XC_INT = 0, XC_FLOAT, XC_STRING};
+
+typedef struct {
+   u_char	type;		/* type is from paramtypes list above */
+   u_char	which;		/* what the parameter represents (P_*) */
+   union {
+      stringpart *string;
+      int	  ivalue;	/* also covers type short int by typecasting */
+      float	  fvalue;
+   } parameter;			/* default or substitution value */
+} oparam, *oparamptr;
+
+typedef struct {
+   u_char	paramno;	/* parameter number to get value from.	   */
+   u_char	pointno;	/* point number in point array, for polygons */
+} eparam, *eparamptr;
+
 /*----------------------------------------------------------------------*/
 /* Generic element type	is a superset of all elements.			*/	
 /*----------------------------------------------------------------------*/
@@ -403,23 +445,10 @@ typedef struct _stringpart {
 typedef struct {
    u_char	type;		/* type is LABEL, POLYGON, etc., from below */
    int		color;
+   eparamptr	passed;
+   u_char	num_params;
 } generic, *genericptr;		/* (convenience function for retypecasting) */
 
-/*----------------------------------------------------------------------*/
-/* Object & object instance parameter structure				*/
-/* (Add types as necessary)						*/
-/*----------------------------------------------------------------------*/
-
-enum paramtypes {XC_SHORT = 0, XC_STRING};
-
-typedef struct {
-   u_char	type;		/* type is from paramtypes list above */
-   union {
-      stringpart *string;
-      short	 svalue;
-   } parameter;			/* default or substitution value */
-} oparam, *oparamptr;
-
 /*----------------------------------------------------------------------*/
 /* Object instance type							*/
 /*----------------------------------------------------------------------*/
@@ -429,11 +458,13 @@ typedef struct _xcobject *objectptr;
 typedef struct {
    u_char	type;
    int		color;
+   eparamptr	passed;		/* numerical parameters passed from above */
+   u_char	num_params;
    XPoint	position;
    short	rotation;
    float	scale;
-   oparamptr    *params;	/* parameter substitutions for this instance */
    objectptr	thisobject;
+   oparamptr    *params;	/* parameter substitutions for this instance */
 } objinst, *objinstptr;
 
 typedef struct _objectpair *objectpairptr;
@@ -451,6 +482,8 @@ typedef struct _objectpair {
 typedef struct {
    u_char	type;
    int		color;
+   eparamptr	passed;		/* numerical parameters passed from above */
+   u_char	num_params;
    XPoint	position;
    short	rotation;
    float	scale;
@@ -468,6 +501,8 @@ typedef struct {
 typedef struct {
    u_char	type;
    int		color;
+   eparamptr	passed;		/* numerical parameters passed from above */
+   u_char	num_params;
    short	style;
    float	width;
    short	number;
@@ -481,6 +516,8 @@ typedef struct {
 typedef struct {
    u_char	type;
    int		color;
+   eparamptr	passed;		/* numerical parameters passed from above */
+   u_char	num_params;
    short	style;
    float	width;
    XPoint	ctrl[4];
@@ -495,6 +532,8 @@ typedef struct {
 typedef struct {
    u_char	type;
    int		color;
+   eparamptr	passed;		/* numerical parameters passed from above */
+   u_char	num_params;
    short	style;
    float	width;
    short	radius; 	/* x-axis radius */
@@ -514,6 +553,8 @@ typedef struct {
 typedef struct {
    u_char	type;
    int		color;
+   eparamptr	passed;		/* numerical parameters passed from above */
+   u_char	num_params;
    short	style;
    float	width;
    short	parts;
@@ -704,14 +745,14 @@ typedef struct {
    Pixel	fg, bg;
    Pixel	gridpix, snappix, selectpix, axespix;
    Pixel	buttonpix, querypix, filterpix;
-   Pixel	auxpix, barpix, bboxpix;
+   Pixel	auxpix, barpix, bboxpix, parampix;
 
    /* color scheme 2 */
 
    Pixel	fg2, bg2;
    Pixel	gridpix2, snappix2, selectpix2, axespix2;
    Pixel	buttonpix2, querypix2, filterpix2;
-   Pixel	auxpix2, barpix2, bboxpix2;
+   Pixel	auxpix2, barpix2, bboxpix2, parampix2;
 
    int		width, height, timeout;
    XFontStruct	*xcfont, *helpfont, *filefont, *textfont, *titlefont;
@@ -800,8 +841,8 @@ enum {
    XCF_Overline, XCF_ISO_Encoding, XCF_Return, XCF_Halfspace, XCF_Quarterspace,
    XCF_Special, XCF_TabStop, XCF_TabForward, XCF_TabBackward,
    XCF_Text_Return, XCF_Text_Delete, XCF_Text_Right, XCF_Text_Left,
-   XCF_Text_Home, XCF_Text_End, XCF_Return_Char,
-   XCF_Parameter, XCF_Edit_Break, XCF_Edit_Delete, XCF_Edit_Insert,
+   XCF_Text_Home, XCF_Text_End, XCF_Return_Char, XCF_Parameter,
+   XCF_Edit_Param, XCF_Edit_Break, XCF_Edit_Delete, XCF_Edit_Insert,
    XCF_Edit_Next, XCF_Attach, XCF_Next_Library, XCF_Library_Directory,
    XCF_Library_Move, XCF_Library_Copy, XCF_Library_Edit, XCF_Library_Delete,
    XCF_Library_Duplicate, XCF_Library_Hide, XCF_Page_Directory, XCF_Library_Pop,
